@@ -2,6 +2,8 @@ mod component_access;
 mod component_ref;
 mod world_data;
 mod world_proxy;
+mod world_wrapper;
 
 pub use world_data::WorldData;
 pub use world_proxy::{WorldProxy, WorldProxyMut};
+pub use world_wrapper::WorldWrapper;
